{ SCALE MONITOR SYSTEM }

CON
   
  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000


VAR

  long  loadin [7]
  long  loadout[7] 
  byte loadoutwt[7]
  byte loadinwt[7] 


OBJ

  LoadInData: "Extended_FDSerial_128ByteBuffers"         'Load-In Serial Driver
  LoadOutData: "Extended_FDSerial_128ByteBuffers"        'Load-Out Serial Driver
  Display: "GUI"                                         'GUI Video Driver
  Debug : "FullDuplexSerial"                             'Debug Serial Driver
  Heart: "Heartbeat"                                     'HeartBeat LED Driver



PUB Start

  dira[9..10]~~

  LoadInData.Start(26,16,2,9600)                         'Start Load-In Comm-Port
  LoadOutData.Start(27,17,2,9600)                        'Start Load-Out Comm-Port
  
  Display.Start                                          'Start Display Driver
  
 'Debug.Start(31,30,0,115200)                            'Start Debug Driver

  Heart.Start(8,500)                                     'Start HeartBeat LED
  
  Main                                                   'Goto Main PUB



PUB Main

  REPEAT
     
    loadin := readloadinwt                               'Store Load-In weight to VAR
    Display.loadin(@loadinwt)                            'Update display driver with Load-In weight

    loadout := readloadoutwt                             'Store Load-Out weight to VAR
    Display.loadout(@loadoutwt)                          'Update display driver with Load-Out weight

    
    if loadin > 2000                                     'Activate Load-In Relay if over limit 
      outa[10]~~                                         'P10 High  
    else                                                 'De-Activate Load-In Relay if under limit
      outa[10]~                                          'P10 Low

    if loadout > 2000                                    'Activate Load-Out Relay if over limit
      outa[9]~~                                          'P9 High
    else                                                 'De-Activate Load-Out Relay if under limit
      outa[9]~                                           'P9 Low



pub readloadinwt | c, n, t                               'Read Load-In Weight

  t := 0                                                 'Reset Time-Out Counter to Zero
  repeat while (c := loadindata.rxtime(100)) <> 2        'Wait for STX   
    ++t                                                  'Add 1 to the Time-Out Counter 
    if t > 25                                            'If Time-Out goes over 25 then return 
      Display.loadin(string("    --"))                   'Display -- if Time-Out occurs 
      return                                             'Return to Main  
  n := 0
  repeat while n < 3                                     'Get 3 Characters, resetting if another rx
    if (c := loadindata.rxtime(100)) == 2
      n := 0
    else
      n++
  result := 0                                            'Get 6 Characters and accumulate them as weight 
  n := 0
  repeat 6
    c := loadindata.rxtime(100)
    loadinwt[n++] := c
    if c <> $20                                          'Ignore leading spaces 
      if c < "0" or c > "9"                              'Make sure we're really reading numbers 
        abort                                            'Abort because something is wrong 
      else                                               'Mask this digit to convert ASCII to numeric and shift into result
        result := (result * 10) + (c & $F)
  loadinwt[n] := 0                                       'Null terminate string result  


pub readloadoutwt | c, n, t                              'Read Load-Out Weight

  t := 0                                                 'Reset Time-Out Counter to Zero
  repeat while (c := loadoutdata.rxtime(100)) <> 2       'Wait for STX
    ++t                                                  'Add 1 to the Time-Out Counter
    if t > 25                                            'If Time-Out goes over 25 then return
      Display.loadout(string("    --"))                  'Display -- if Time-Out occurs
      return                                             'Return to Main
  n := 0
  repeat while n < 3                                     'Get 3 Characters, resetting if another rx
    if (c := loadoutdata.rxtime(100)) == 2
      n := 0
    else
      n++
  result := 0                                            'Get 6 Characters and accumulate them as weight
  n := 0
  repeat 6
    c := loadoutdata.rxtime(100)
    loadoutwt[n++] := c
    if c <> $20                                          'Ignore leading spaces
      if c < "0" or c > "9"                              'Make sure we're really reading numbers
        abort                                            'Abort because something is wrong
      else                                               'Mask this digit to convert ASCII to numeric and shift into result
        result := (result * 10) + (c & $F)
  loadoutwt[n] := 0                                      'Null terminate string result
  